@@ -26,7 +26,7 @@
 #include <glib/gi18n.h>
 #include <gtk/gtkx.h>
 
-#include <vinagre/vinagre-utils.h>
+#include "vinagre/vinagre-util.h"
 #include <vinagre/vinagre-prefs.h>
 
 #include "vinagre-rdp-tab.h"
@@ -121,7 +121,7 @@ delay_connect (GObject *object)
 		      &rdp_tab->priv->pid,
 		      &error))
     {
-      vinagre_utils_show_error (_("Error while executing rdesktop"),
+      vinagre_utils_show_error_dialog (_("Error while executing rdesktop"),
 				error ? error->message : _("Unknown error"),
 				GTK_WINDOW (vinagre_tab_get_window (tab)));
       vinagre_tab_remove_from_notebook (tab);
