@@ -24,7 +24,7 @@
 #include <vncdisplay.h>
 #include <gdk/gdkkeysyms.h>
 
-#include <vinagre/vinagre-utils.h>
+#include "vinagre/vinagre-util.h"
 #include <vinagre/vinagre-prefs.h>
 
 #include "vinagre-vnc-tab.h"
@@ -293,7 +293,7 @@ open_vnc (VinagreVncTab *vnc_tab)
 	if (!vinagre_vnc_tunnel_create (window, &host, &port_str, ssh_tunnel_host, &error))
 	  {
 	    success = FALSE;
-	    vinagre_utils_show_error (_("Error creating the SSH tunnel"),
+	    vinagre_utils_show_error_dialog (_("Error creating the SSH tunnel"),
 				      error ? error->message : _("Unknown reason"),
 				      window);
 	    goto out;
@@ -304,7 +304,7 @@ open_vnc (VinagreVncTab *vnc_tab)
   if (success)
     gtk_widget_grab_focus (GTK_WIDGET (vnc));
   else
-    vinagre_utils_show_error (_("Error connecting to host."),
+    vinagre_utils_show_error_dialog (_("Error connecting to host."),
 			      error ? error->message : _("Unknown reason"),
 			      window);
 
@@ -353,7 +353,7 @@ vnc_auth_unsupported_cb (VncDisplay *vnc, guint auth_type, VinagreVncTab *vnc_ta
 		   emphasis,
 		   auth_type);
 
-  vinagre_utils_show_error (_("Authentication unsupported"),
+  vinagre_utils_show_error_dialog (_("Authentication unsupported"),
 			    message->str,
 			    GTK_WINDOW (vinagre_tab_get_window (tab)));
   g_string_free (message, TRUE);
@@ -521,8 +521,8 @@ vnc_authentication_cb (VncDisplay *vnc, GValueArray *credList, VinagreVncTab *vn
 	  else
 	    {
 	      vinagre_tab_remove_from_notebook (tab);
-	      vinagre_utils_show_error (_("Authentication error"),
-					_("A username is required in order to access this machine."),
+	      vinagre_utils_show_error_dialog (_("Authentication error"),
+					_("A username is required in order to access this remote desktop."),
 					window);
 	      goto out;
 	    }
@@ -538,8 +538,8 @@ vnc_authentication_cb (VncDisplay *vnc, GValueArray *credList, VinagreVncTab *vn
 	  else
 	    {
 	      vinagre_tab_remove_from_notebook (tab);
-	      vinagre_utils_show_error (_("Authentication error"),
-					_("A password is required in order to access this machine."),
+	      vinagre_utils_show_error_dialog (_("Authentication error"),
+					_("A password is required in order to access this remote desktop."),
 					window);
 	      goto out;
 	    }
@@ -666,15 +666,15 @@ create_initialized_actions (VinagreVncTab *tab)
   GSList *list = NULL;
   VinagreTabUiAction *a;
 
-  /* Machine->Send CTRL-ALT-DEL */
+  /* Remote->Send CTRL-ALT-DEL */
   a = g_new (VinagreTabUiAction, 1);
   a->paths = g_new (gchar *, 3);
-  a->paths[0] = g_strdup ("/MenuBar/MachineMenu/MachineOps_1");
+  a->paths[0] = g_strdup ("/MenuBar/RemoteMenu/RemoteOps_1");
   a->paths[1] = g_strdup ("/ToolBar");
   a->paths[2] = NULL;
-  a->action = gtk_action_new ("VNCMachineSendCtrlAltDel",
+  a->action = gtk_action_new ("VNCRemoteSendCtrlAltDel",
 			      _("_Send Ctrl-Alt-Del"),
-			      _("Sends Ctrl+Alt+Del to the remote machine"),
+			      _("Sends Ctrl+Alt+Del to the remote desktop"),
 			      "preferences-desktop-keyboard-shortcuts");
   gtk_action_set_is_important (a->action, TRUE);
   gtk_action_set_icon_name (a->action, "preferences-desktop-keyboard-shortcuts");
@@ -910,7 +910,7 @@ vinagre_vnc_tab_set_scaling (VinagreVncTab *tab, gboolean active) {
   vnc_display_set_force_size (VNC_DISPLAY(tab->priv->vnc), !active);
   if (!vnc_display_set_scaling (VNC_DISPLAY (tab->priv->vnc), active))
     {
-      vinagre_utils_show_error (NULL, _("Scaling is not supported on this installation.\n\nRead the README file (shipped with Vinagre) in order to know how to enable this feature."),
+      vinagre_utils_show_error_dialog (NULL, _("Scaling is not supported on this installation.\n\nRead the README file (shipped with Vinagre) in order to know how to enable this feature."),
 				GTK_WINDOW (vinagre_tab_get_window (VINAGRE_TAB (tab))));
       return FALSE;
     }
