@@ -24,7 +24,7 @@
 
 #include <glib/gi18n.h>
 #include "vinagre-fav.h"
-#include "vinagre-utils.h"
+#include "vinagre-util.h"
 #include "vinagre-dnd.h"
 #include "vinagre-bookmarks.h"
 #include "vinagre-bookmarks-ui.h"
@@ -33,7 +33,7 @@
 #include "vinagre-plugins-engine.h"
 #include "vinagre-commands.h"
 
-#ifdef VINAGRE_ENABLE_AVAHI
+#ifdef VINAGRE_HAVE_AVAHI
 #include "vinagre-mdns.h"
 #endif
 
@@ -219,7 +219,7 @@ menu_position (GtkMenu    *menu,
 {
   GtkTreePath *path;
   GdkRectangle rect;
-  gint wx, wy;
+  gint wy;
   GtkRequisition requisition;
   GtkWidget *w;
   GtkAllocation allocation;
@@ -232,7 +232,6 @@ menu_position (GtkMenu    *menu,
 			       NULL,
 			       &rect);
 
-  wx = rect.x;
   wy = rect.y;
 
   gdk_window_get_origin (gtk_widget_get_window (w), x, y);
@@ -567,14 +566,14 @@ vinagre_fav_bookmarks_open (GtkAction  *action,
 
 static const GtkActionEntry always_sensitive_actions[] =
 {
-  {"BookmarksNewFolder", "folder-new", N_("_New Folder"), NULL,
+  {"BookmarksNewFolder", "folder-new", N_("_New folder"), NULL,
     N_("Create a new folder"), G_CALLBACK (vinagre_fav_bookmarks_new_folder) },
 };
 
 static const GtkActionEntry actions[] =
 {
   { "BookmarksOpen", GTK_STOCK_CONNECT, N_("_Open bookmark"), NULL,
-    N_("Connect to this machine"), G_CALLBACK (vinagre_fav_bookmarks_open) },
+    N_("Connect to this remote desktop"), G_CALLBACK (vinagre_fav_bookmarks_open) },
   {"BookmarksEdit", GTK_STOCK_EDIT, N_("_Edit bookmark"), NULL,
     N_("Edit the details of selected bookmark"), G_CALLBACK (vinagre_fav_bookmarks_edit) },
   {"BookmarksDel", GTK_STOCK_DELETE, N_("_Remove from bookmarks"), NULL,
@@ -620,6 +619,10 @@ vinagre_fav_create_toolbar (VinagreFav *fav)
   fav->priv->always_sensitive_action_group = action_group;
 
   toolbar = gtk_ui_manager_get_widget (manager, "/FavToolBar");
+  gtk_style_context_add_class (gtk_widget_get_style_context (toolbar),
+                               GTK_STYLE_CLASS_INLINE_TOOLBAR);
+  gtk_style_context_set_junction_sides (gtk_widget_get_style_context (toolbar),
+                                        GTK_JUNCTION_BOTTOM);
   gtk_toolbar_set_style (GTK_TOOLBAR (toolbar), GTK_TOOLBAR_ICONS);
   gtk_toolbar_set_icon_size (GTK_TOOLBAR (toolbar), GTK_ICON_SIZE_MENU);
 
@@ -642,7 +645,9 @@ vinagre_fav_create_tree (VinagreFav *fav)
 				  GTK_POLICY_AUTOMATIC);
 
   gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scroll),
-				       GTK_SHADOW_ETCHED_OUT);
+				       GTK_SHADOW_IN);
+  gtk_style_context_set_junction_sides (gtk_widget_get_style_context (scroll),
+                                        GTK_JUNCTION_TOP);
 
   gtk_box_pack_start (fav->priv->box, scroll, TRUE, TRUE, 0);
 
@@ -753,7 +758,7 @@ drag_data_received_handl (GtkWidget *widget,
       info = g_strsplit (_sdata, "||", 2);
       if (g_strv_length (info) != 2)
 	{
-	  vinagre_utils_show_error (_("Invalid operation"),
+	  vinagre_utils_show_error_dialog (_("Invalid operation"),
 				    _("Data received from drag&drop operation is invalid."),
 				    GTK_WINDOW (fav->priv->window));
 	  return;
@@ -763,7 +768,7 @@ drag_data_received_handl (GtkWidget *widget,
       if (!conn)
 	{
 	  g_strfreev (info);
-	  vinagre_utils_show_error (NULL,
+	  vinagre_utils_show_error_dialog (NULL,
 				    error ? error : _("Unknown error"),
 				    GTK_WINDOW (fav->priv->window));
 	  g_free (error);
@@ -839,6 +844,32 @@ vinagre_fav_hide (GtkButton *button, VinagreFav *fav)
   gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action), FALSE);
 }
 
+static GtkWidget *
+_create_small_close_button ()
+{
+  GtkRcStyle *rcstyle;
+  GtkWidget *image;
+  GtkWidget *close_button;
+
+  close_button = gtk_button_new ();
+  gtk_button_set_relief (GTK_BUTTON (close_button),
+			 GTK_RELIEF_NONE);
+  /* don't allow focus on the close button */
+  gtk_button_set_focus_on_click (GTK_BUTTON (close_button), FALSE);
+
+  /* make it as small as possible */
+  rcstyle = gtk_rc_style_new ();
+  rcstyle->xthickness = rcstyle->ythickness = 0;
+  gtk_widget_modify_style (close_button, rcstyle);
+  g_object_unref (rcstyle),
+
+  image = gtk_image_new_from_stock (GTK_STOCK_CLOSE,
+				    GTK_ICON_SIZE_MENU);
+  gtk_container_add (GTK_CONTAINER (close_button), image);
+
+  return close_button;
+}
+
 static void
 vinagre_fav_create_title (VinagreFav *fav)
 {
@@ -858,7 +889,7 @@ vinagre_fav_create_title (VinagreFav *fav)
   gtk_box_pack_start (GTK_BOX (box), label, TRUE, TRUE, 0);
 
   /* setup small close button */
-  close_button = vinagre_utils_create_small_close_button ();
+  close_button = _create_small_close_button ();
   gtk_box_pack_start (GTK_BOX (box), close_button, FALSE, FALSE, 0);
   gtk_widget_set_tooltip_text (close_button, _("Hide panel"));
   g_signal_connect (close_button,
@@ -910,7 +941,7 @@ vinagre_fav_constructed (GObject *object)
                             "changed",
                             G_CALLBACK (vinagre_fav_update_list),
                             fav);
-#ifdef VINAGRE_ENABLE_AVAHI
+#ifdef VINAGRE_HAVE_AVAHI
   g_signal_connect_swapped (vinagre_mdns_get_default (),
                             "changed",
                             G_CALLBACK (vinagre_fav_update_list),
@@ -1058,7 +1089,7 @@ vinagre_fav_update_list (VinagreFav *fav)
 
   vinagre_fav_fill_bookmarks (store, list, NULL, FALSE);
 
-#ifdef VINAGRE_ENABLE_AVAHI
+#ifdef VINAGRE_HAVE_AVAHI
   list = vinagre_mdns_get_all (vinagre_mdns_get_default ());
   if (!list)
     return FALSE;
