@@ -24,7 +24,7 @@
 
 #include <glib/gi18n.h>
 
-#include "vinagre-utils.h"
+#include "vinagre-util.h"
 #include "vinagre-dnd.h"
 #include "vinagre-prefs.h"
 
@@ -211,7 +211,7 @@ vinagre_notebook_update_ui_sentitivity (VinagreNotebook *nb)
 	   (vinagre_tab_get_state (VINAGRE_TAB (nb->priv->active_tab)) == VINAGRE_TAB_STATE_CONNECTED);
   gtk_action_group_set_sensitive (action_group, active);
 
-  action = gtk_action_group_get_action (action_group, "MachineTakeScreenshot");
+  action = gtk_action_group_get_action (action_group, "RemoteTakeScreenshot");
   gtk_action_set_sensitive (action, active &&
 				    nb->priv->active_tab &&
 				    vinagre_tab_get_has_screenshot (nb->priv->active_tab));
@@ -461,7 +461,7 @@ tab_disconnected_cb (VinagreTab *tab, VinagreNotebook *nb)
   /* Translators: %s is a host name or IP address. */
   message = g_strdup_printf (_("Connection to host %s was closed."),
 			     emphasis);
-  vinagre_utils_show_error (_("Connection closed"), message, GTK_WINDOW (nb->priv->window));
+  vinagre_utils_show_error_dialog (_("Connection closed"), message, GTK_WINDOW (nb->priv->window));
   g_free (message);
   g_free (name);
   g_free (emphasis);
@@ -486,7 +486,7 @@ tab_auth_failed_cb (VinagreTab *tab, const gchar *msg, VinagreNotebook *nb)
   	g_string_append_printf (message, " (%s)", msg);
   g_string_append_c (message, '.');
 
-  vinagre_utils_show_error (_("Authentication failed"), message->str, GTK_WINDOW (nb->priv->window));
+  vinagre_utils_show_error_dialog (_("Authentication failed"), message->str, GTK_WINDOW (nb->priv->window));
   g_string_free (message, TRUE);
   g_free (name);
   g_free (emphasis);
