@@ -21,6 +21,8 @@
 #ifndef __VINAGRE_WINDOW_PRIVATE_H__
 #define __VINAGRE_WINDOW_PRIVATE_H__
 
+#include <libpeas/peas-extension-set.h>
+
 #include "vinagre-window.h"
 #include "vinagre-notebook.h"
 
@@ -42,8 +44,8 @@ struct _VinagreWindowPrivate
   GtkUIManager   *manager;
 
   GtkActionGroup *always_sensitive_action_group;
-  GtkActionGroup *machine_connected_action_group;
-  GtkActionGroup *machine_initialized_action_group;
+  GtkActionGroup *remote_connected_action_group;
+  GtkActionGroup *remote_initialized_action_group;
 
   GtkActionGroup *bookmarks_list_action_group;
   GtkActionGroup *recent_action_group;
@@ -55,6 +57,8 @@ struct _VinagreWindowPrivate
   GtkWidget       *toolbar;
   GtkWidget       *menubar;
 
+  PeasExtensionSet *extensions;
+
   gint            width;
   gint            height;
   GdkWindowState  window_state;
