@@ -37,7 +37,7 @@
 #include "vinagre-fav.h"
 #include "vinagre-prefs.h"
 #include "vinagre-cache-prefs.h"
-#include "vinagre-utils.h"
+#include "vinagre-util.h"
 #include "vinagre-bookmarks.h"
 #include "vinagre-ui.h"
 #include "vinagre-window-private.h"
@@ -55,6 +55,16 @@
 
 G_DEFINE_TYPE(VinagreWindow, vinagre_window, GTK_TYPE_WINDOW)
 
+static const gchar * _get_ui_xml_filename (void)
+{
+    static const gchar ui_xml_file[] = "vinagre-ui.xml";
+
+    if (g_file_test (ui_xml_file, G_FILE_TEST_EXISTS))
+        return ui_xml_file;
+    else
+        return g_build_filename (VINAGRE_DATADIR, ui_xml_file, NULL);
+}
+
 static void
 vinagre_window_dispose (GObject *object)
 {
@@ -275,7 +285,7 @@ activate_recent_cb (GtkRecentChooser *action, VinagreWindow *window)
       g_object_unref (conn);
     }
   else
-    vinagre_utils_show_error (NULL, error ? error : _("Unknown error"), GTK_WINDOW (window));
+    vinagre_utils_show_error_dialog (NULL, error ? error : _("Unknown error"), GTK_WINDOW (window));
 
   g_free (error);
   g_free (uri);
@@ -295,7 +305,7 @@ update_recent_connections (VinagreWindow *window)
 
   gtk_ui_manager_add_ui (p->manager,
 			 p->recents_menu_ui_id,
-			 "/MenuBar/MachineMenu/FileRecentsPlaceholder",
+			 "/MenuBar/RemoteMenu/FileRecentsPlaceholder",
 			 "recent_connections",
 			 "recent_connections",
 			 GTK_UI_MANAGER_MENUITEM,
@@ -366,43 +376,35 @@ create_menu_bar_and_toolbar (VinagreWindow *window,
   g_object_unref (action_group);
   window->priv->always_sensitive_action_group = action_group;
 
-  action = gtk_action_group_get_action (action_group, "MachineConnect");
-  g_object_set (action, "is_important", TRUE, NULL);
+  action = gtk_action_group_get_action (action_group, "RemoteConnect");
+  gtk_action_set_is_important (action, TRUE);
 
-  /* Machine connected actions */
-  action_group = gtk_action_group_new ("VinagreWindowMachineConnectedActions");
+  /* Remote connected actions */
+  action_group = gtk_action_group_new ("VinagreWindowRemoteConnectedActions");
   gtk_action_group_set_translation_domain (action_group, NULL);
   gtk_action_group_add_actions (action_group,
-				vinagre_machine_connected_entries,
-				G_N_ELEMENTS (vinagre_machine_connected_entries),
+				vinagre_remote_connected_entries,
+				G_N_ELEMENTS (vinagre_remote_connected_entries),
 				window);
   gtk_action_group_set_sensitive (action_group, FALSE);
   gtk_ui_manager_insert_action_group (manager, action_group, 0);
   g_object_unref (action_group);
-  window->priv->machine_connected_action_group = action_group;
+  window->priv->remote_connected_action_group = action_group;
 
-  action = gtk_action_group_get_action (action_group, "MachineClose");
-  g_object_set (action, "is_important", TRUE, NULL);
-
-  /* Machine initialized actions */
-  action_group = gtk_action_group_new ("VinagreWindowMachineInitializedActions");
+  /* Remote initialized actions */
+  action_group = gtk_action_group_new ("VinagreWindowRemoteInitializedActions");
   gtk_action_group_set_translation_domain (action_group, NULL);
   gtk_action_group_add_actions (action_group,
-				vinagre_machine_initialized_entries,
-				G_N_ELEMENTS (vinagre_machine_initialized_entries),
+				vinagre_remote_initialized_entries,
+				G_N_ELEMENTS (vinagre_remote_initialized_entries),
 				window);
   gtk_action_group_set_sensitive (action_group, FALSE);
   gtk_ui_manager_insert_action_group (manager, action_group, 0);
   g_object_unref (action_group);
-  window->priv->machine_initialized_action_group = action_group;
-
-  action = gtk_action_group_get_action (action_group, "ViewFullScreen");
-  g_object_set (action, "is_important", TRUE, NULL);
-  action = gtk_action_group_get_action (action_group, "MachineTakeScreenshot");
-  g_object_set (action, "is_important", TRUE, NULL);
+  window->priv->remote_initialized_action_group = action_group;
 
   /* now load the UI definition */
-  gtk_ui_manager_add_ui_from_file (manager, vinagre_utils_get_ui_xml_filename (), &error);
+  gtk_ui_manager_add_ui_from_file (manager, _get_ui_xml_filename (), &error);
   if (error != NULL)
     {
       g_critical (_("Could not merge UI XML file: %s"), error->message);
@@ -436,7 +438,7 @@ create_menu_bar_and_toolbar (VinagreWindow *window,
 
   /* Recent connections */
   window->priv->recent_action = gtk_recent_action_new ("recent_connections",
-						     _("_Recent connections"),
+						     _("_Recent Connections"),
 						       NULL, NULL);
   g_object_set (G_OBJECT (window->priv->recent_action),
 		"show-not-found", TRUE,
@@ -734,11 +736,11 @@ vinagre_window_check_first_run (VinagreWindow *window)
 						  GTK_BUTTONS_CLOSE,
 						  _("About menu accelerators and keyboard shortcuts"));
       gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-						_("Vinagre comes with menu accelerators and keyboard shortcuts disabled by default. The reason is to avoid the keys to be intercepted by the program, and allow them to be sent to the remote machine.\n\nYou can change this behavior through the preferences dialog. For more information, check the documentation.\n\nThis message will appear only once."));     
+						_("Vinagre comes with menu accelerators and keyboard shortcuts disabled by default. The reason is to avoid the keys from being intercepted by the program, and allow them to be sent to the remote desktop.\n\nYou can change this behavior through the preferences dialog. For more information, check the documentation.\n\nThis message will appear only once."));
       gtk_dialog_run (GTK_DIALOG (dialog));
       gtk_widget_destroy (dialog);
 
-      if (vinagre_utils_create_dir (filename, &error))
+      if (vinagre_utils_create_dir_for_file (filename, &error))
         {
           int fd = g_creat (filename, 0644);
           if (fd < 0)
@@ -979,7 +981,7 @@ vinagre_window_get_initialized_action (VinagreWindow *window)
 {
   g_return_val_if_fail (VINAGRE_IS_WINDOW (window), NULL);
 
-  return window->priv->machine_initialized_action_group;
+  return window->priv->remote_initialized_action_group;
 }
 
 /**
@@ -1007,7 +1009,7 @@ vinagre_window_get_connected_action (VinagreWindow *window)
 {
   g_return_val_if_fail (VINAGRE_IS_WINDOW (window), NULL);
 
-  return window->priv->machine_connected_action_group;
+  return window->priv->remote_connected_action_group;
 }
 
 /**
